@@ -2,7 +2,7 @@
 
 from .date import random_date, random_datetime
 from .decimal import random_decimal
-from .int import random_int
+from .int import random_fixed_int
 from .time import random_timestamp
 
 __all__ = [
@@ -10,5 +10,5 @@ __all__ = [
     "random_datetime",
     "random_timestamp",
     "random_decimal",
-    "random_int",
+    "random_fixed_int",
 ]
